@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Japanese DateTime Parser/Formatter - ~/lib/DateTime/Format/JP.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/07/18
-## Modified 2021/07/18
+## Modified 2021/07/22
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -18,7 +18,7 @@ BEGIN
     use warnings::register;
     use parent qw( Exporter );
     use Nice::Try;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
     our $DICT = [];
     our $ZENKAKU_NUMBERS = [];
     our $KANJI_NUMBERS   = [];
@@ -413,7 +413,6 @@ sub new
     # pattern
     # time_zone
     # traditional
-    # weekday
     # zenkaku / hankaku
     if( exists( $p->{hankaku} ) && !exists( $p->{zenkaku} ) )
     {
@@ -1135,8 +1134,6 @@ sub time_zone { return( shift->_set_get( 'time_zone', @_ ) ); }
 
 sub traditional { return( shift->_set_get( 'traditional', @_ ) ); }
 
-sub weekday { return( shift->_set_get( 'weekday', @_ ) ); }
-
 sub zenkaku { return( shift->_set_get_zenkaku( 'zenkaku', @_ ) ); }
 
 sub zenkaku_to_romaji { return( shift->_get_pos_in_array( $ZENKAKU_NUMBERS, @_ ) ); }
@@ -1325,15 +1322,15 @@ DateTime::Format::JP - Japanese DateTime Parser and Formatter
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
 This module is used to parse and format Japanese date and time. It is lightweight and yet versatile.
 
-It implements 2 main methods: L</parse_datetime> and L</format_datetime> both expects and return decoded utf8 string.
+It implements 2 main methods: L</parse_datetime> and L</format_datetime> both expect and return decoded utf8 string.
 
-You can use L<Encode> to decode and encode from perl internal utf8 representation to real utf8.
+You can use L<Encode> to decode and encode from perl internal utf8 representation to real utf8 and vice versa.
 
 =head1 METHODS
 
@@ -1385,7 +1382,7 @@ All method in this module return C<undef> upon error and set an error that can b
 
 Takes a L<DateTime> object and returns a formatted date and time based on the pattern specified, which defaults to C<%c>. 
 
-You can call this method directly, or you can set this formatter object in <DateTime/set_formatter> so that ie will be used for stringification of the L<DateTime> object.
+You can call this method directly, or you can set this formatter object in L<DateTime/set_formatter> so that ie will be used for stringification of the L<DateTime> object.
 
 See below L</"PATTERN TOKENS"> for the available tokens and their meanings.
 
@@ -1433,10 +1430,14 @@ Returns a L<DateTime> based on parameters provided.
 
 =head2 romaji_to_kanji
 
-Takes a number and returns its equivalent representation in Japanese kanji. Thus, for example, C<1234> would be returned as C<一千二百三十四>
+Takes a number and returns its equivalent representation in Japanese kanji. Thus, for example, C<1234> would be returned as C<千二百三十四>
 
 Please note that, since this is intended to be used only for dates, it does not format number over 9 thousand. If you think there is such need, please contact the author.
 
+=head2 romaji_to_kanji_simple
+
+Replaces numbers with their Japanese kanji equivalent. It does not use numerals.
+
 =head2 romaji_to_zenkaku
 
 Takes a number and returns its equivalent representation in double-byte Japanese numbers. Thus, for example, C<1234> would be returned as C<１２３４>
@@ -1493,7 +1494,7 @@ And if I<zenkaku> is true, it will use double-byte numbers instead:
 
 And if I<kanji_number> is true, it will then be:
 
-    令和3年七月十二日午後二時十七分三十秒
+    令和三年七月十二日午後二時十七分三十秒
 
 =item * %C
 
@@ -1625,7 +1626,7 @@ However, if I<zenkaku> is true, then it would rather use full width (全角) num
 
 And if I<kanji_number> is true, it will then be something like C<六十秒>
 
-60 may occur for leap seconds. See L<DateTime::LeapSecond>).
+(60 may occur for leap seconds. See L<DateTime::LeapSecond>).
 
 =item * %t
 
@@ -1677,7 +1678,7 @@ However, if I<zenkaku> is true, then it would rather be:
 
 And if I<kanji_number> is true, it will then be:
 
-    令和3年七月十二日
+    令和三年七月十二日
 
 =item * %X
 
@@ -1748,11 +1749,13 @@ Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
 
 =head1 SEE ALSO
 
-L<perl>
+L<DateTime>
 
 =head1 COPYRIGHT & LICENSE
 
 Copyright(c) 2021 DEGUEST Pte. Ltd. DEGUEST Pte. Ltd.
 
-=cut
+You can use, copy, modify and redistribute this package and associated
+files under the same terms as Perl itself.
 
+=cut
